@@ -63,8 +63,11 @@ module RuboCop
         irange:              RangeNode,
         erange:              RangeNode,
         kwargs:              HashNode,
+        kwbegin:             KeywordBeginNode,
         kwsplat:             KeywordSplatNode,
         lambda:              LambdaNode,
+        masgn:               MasgnNode,
+        mlhs:                MlhsNode,
         module:              ModuleNode,
         next:                NextNode,
         op_asgn:             OpAsgnNode,
@@ -72,6 +75,7 @@ module RuboCop
         or:                  OrNode,
         pair:                PairNode,
         procarg0:            Procarg0Node,
+        rational:            RationalNode,
         regexp:              RegexpNode,
         rescue:              RescueNode,
         resbody:             ResbodyNode,
@@ -86,6 +90,10 @@ module RuboCop
         sym:                 SymbolNode,
         until:               UntilNode,
         until_post:          UntilNode,
+        lvar:                VarNode,
+        ivar:                VarNode,
+        cvar:                VarNode,
+        gvar:                VarNode,
         when:                WhenNode,
         while:               WhileNode,
         while_post:          WhileNode,
