@@ -105,7 +105,7 @@ module RuboCop
       #
       # @return [Boolean] whether the dispatched method is a setter
       def setter_method?
-        loc.respond_to?(:operator) && loc.operator
+        loc?(:operator)
       end
       alias assignment? setter_method?
 
@@ -117,7 +117,7 @@ module RuboCop
       #
       # @return [Boolean] whether the method was called with a connecting dot
       def dot?
-        loc.respond_to?(:dot) && loc.dot && loc.dot.is?('.')
+        loc_is?(:dot, '.')
       end
 
       # Checks whether the dispatched method uses a double colon to connect the
@@ -125,7 +125,7 @@ module RuboCop
       #
       # @return [Boolean] whether the method was called with a connecting dot
       def double_colon?
-        loc.respond_to?(:dot) && loc.dot && loc.dot.is?('::')
+        loc_is?(:dot, '::')
       end
 
       # Checks whether the dispatched method uses a safe navigation operator to
@@ -133,7 +133,7 @@ module RuboCop
       #
       # @return [Boolean] whether the method was called with a connecting dot
       def safe_navigation?
-        loc.respond_to?(:dot) && loc.dot && loc.dot.is?('&.')
+        loc_is?(:dot, '&.')
       end
 
       # Checks whether the *explicit* receiver of this method dispatch is
@@ -165,7 +165,7 @@ module RuboCop
       #
       # @return [Boolean] whether the dispatched method has a block
       def block_literal?
-        (parent&.block_type? || parent&.numblock_type?) && eql?(parent.send_node)
+        parent&.any_block_type? && eql?(parent.send_node)
       end
 
       # Checks whether this node is an arithmetic operation
@@ -201,7 +201,7 @@ module RuboCop
 
         return unless node.send_type? && node.receiver.nil? && arg.is_a?(::AST::Node)
 
-        return arg if arg.def_type? || arg.defs_type?
+        return arg if arg.type?(:def, :defs)
 
         def_modifier(arg)
       end
@@ -260,7 +260,7 @@ module RuboCop
           ^{                                       # or the parent is...
             sclass class module class_constructor? # a class-like node
             [ {                                    # or some "wrapper"
-                kwbegin begin block numblock
+                kwbegin begin any_block
                 (if _condition <%0 _>)  # note: we're excluding the condition of `if` nodes
               }
               #in_macro_scope?                     # that is itself in a macro scope
@@ -281,7 +281,7 @@ module RuboCop
 
       # @!method non_bare_access_modifier_declaration?(node = self)
       def_node_matcher :non_bare_access_modifier_declaration?, <<~PATTERN
-        (send nil? {:public :protected :private :module_function} _)
+        (send nil? {:public :protected :private :module_function} _+)
       PATTERN
     end
   end
